@@ -94,7 +94,7 @@ def execute(cls, sql):
 
 
 @special_command("help", "Show this help.")
-def show_help(arg):
+def show_help(cls, arg):
     headers = ["Command", "Description"]
     result = []
 
@@ -102,9 +102,15 @@ def show_help(arg):
         if not value.hidden:
             for m_desc in value.description.split('\n'):
                 result.append((value.command, m_desc))
-    return [(None, result, headers, None, None)]
+        return [{
+            "title": None,
+            "rows": result,
+            "headers": headers,
+            "columntypes": None,
+            "status": None
+        }, ]
 
 
 @special_command("quit", "Quit.")
-def quit_sqlcli(arg):
+def quit_sqlcli(cls, arg):
     raise EOFError
